@@ -115,8 +115,10 @@ bool CantorShell::hasAvailableBackend()
 
 void CantorShell::setupActions()
 {
-    KStandardAction::openNew(this, SLOT(fileNew()), actionCollection());
-    KStandardAction::open(this, SLOT(fileOpen()), actionCollection());
+    KAction* openNew = KStandardAction::openNew(this, SLOT(fileNew()), actionCollection());
+    openNew->setPriority(QAction::LowPriority);
+    KAction* open = KStandardAction::open(this, SLOT(fileOpen()), actionCollection());
+    open->setPriority(QAction::LowPriority);
 
     KStandardAction::close (this,  SLOT(closeTab()),  actionCollection());
 
@@ -484,6 +486,8 @@ void CantorShell::updatePanel()
             tabifyDockWidget(last, docker);
         last=docker;
 
+        connect(plugin, SIGNAL(visibilityRequested()), docker, SLOT(raise()));
+
         m_panels.append(docker);
 
         //Create the action to show/hide this panel
