@@ -88,7 +88,13 @@ class CANTOR_EXPORT ScriptExtension : public Extension
      * @return file filter used for Script Files (e.g. *.py)
      */
     virtual QString scriptFileFilter() = 0;
-
+    /**
+     * returns the name of the language to use for syntax highlighting
+     * in the script editor (e.g. python). The value returned must match
+     * the name attribute from the xml language description in KTexteditor.
+     * @return name of the language to use for syntax highlighting (e.g. python)
+     */
+    virtual QString highlightingMode() = 0;
     /**
      * returns a string used to separate commands (usually ;)
      * @return a string used to separate commands (usually ;)
